@@ -1,17 +1,15 @@
 package Dancer::Logger::PSGI;
-BEGIN {
-  $Dancer::Logger::PSGI::VERSION = '0.03';
-}
-
-# ABSTRACT: PSGI Log handler for Dancer
 
+use v5.10;
 use strict;
 use warnings;
-
 use Dancer::SharedData;
-use base 'Dancer::Logger::Abstract';
+use parent qw(Dancer::Logger::Abstract);
 
-sub init {}
+our $VERSION = 'v1.0.0'; # VERSION
+# ABSTRACT: PSGI Log handler for Dancer
+
+sub init { }
 
 sub _log {
     my ( $self, $level, $message ) = @_;
@@ -19,29 +17,18 @@ sub _log {
     chomp $full_message;
 
     my $request = Dancer::SharedData->request;
-    if ($request->{env}->{'psgix.logger'}) {
-        $request->{env}->{'psgix.logger'}->(
+    if ($request->{env}{"psgix.logger"}) {
+        $request->{env}{"psgix.logger"}->(
             {   level   => $level,
                 message => $full_message,
             }
         );
     }
+    return;
 }
 
 1;
 
-
-__END__
-=pod
-
-=head1 NAME
-
-Dancer::Logger::PSGI - PSGI Log handler for Dancer
-
-=head1 VERSION
-
-version 0.03
-
 =head1 SYNOPSIS
 
 In your Dancer's environment file:
@@ -55,7 +42,7 @@ In your application
 
     warning "this is a warning"
 
-With L<Plack::Middleware::ConsoleLogger>, all your log will be send to the javascript console of your browser.
+With L<Plack::Middleware::ConsoleLogger>, all your log will be send to the JavaScript console of your browser.
 
 =head1 DESCRIPTION
 
@@ -73,4 +60,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
